@@ -71,7 +71,7 @@ class Domoticz(IPlugin):
 		inten = jsonInput['outcome']['entities']['body']
  		log.msg("inten :  %s" % (inten)
 #		if jsonInput['outcome']['entities']['location']['body'] :
-#			location = jsonInput['outcome']['entities']['location']['body']
+			location = jsonInput['outcome']['entities']['location']['body']
 #		else:
 #			bodies = "pas de lieu"
 #			location= "VIDE"
@@ -80,7 +80,7 @@ class Domoticz(IPlugin):
 #		else:
 #			bodies = "pas de local_search_query"
 #
-		idex= local + " " + location +  "_"
+		idex= location +  "_"
 		log.msg("idex :  %s" % (idex))		
 #		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
 		for rs in self.configuration_plugin['param_dz']:
